Changelog
=========


1.0a2 (2017-09-07)
------------------

- Fix tests / static code analysis and stream demo video from Youtube
  [tomgross]


1.0a1 (2017-09-07)
------------------

- Initial release.
  [tomgross]
